<?php
/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * WordPress XML-RPC Comment関連API
 *
 * Comment関連APIのクライアント
 *
 * PHP version 5
 *
 * LICENSE: This LICENSE is in the New BSD license style.
 *
 * @category  WordPress
 * @package   WordPress_Core
 * @author    Takahiro Ooishi <taka0125@users.sourceforge.jp>
 * @version   SVN : $Id$
 * @copyright 2009 Takahiro Ooishi
 * @license   http://opensource.org/licenses/bsd-license.php New BSD License
 * @link      http://code.google.com/p/wpalforphp/wiki/WordPressCoreCommentAPI
 * @see       http://codex.wordpress.org/XML-RPC_wp
 */

/**
 * WordPress XML-RPC Comment関連API
 *
 * Comment関連APIのクライアント
 *
 * @category  WordPress
 * @package   WordPress_Core
 * @abstract
 * @author    Takahiro Ooishi <taka0125@users.sourceforge.jp>
 * @version   Release: @package_version@
 * @copyright 2009 Takahiro Ooishi
 * @license   http://opensource.org/licenses/bsd-license.php New BSD License
 * @link      http://code.google.com/p/wpalforphp/wiki/WordPressCoreCommentAPI
 *
 */
class WordPress_Core_CommentAPI extends WordPress_API
{
    function getComments($comment)
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
            $comment
        );

        $request = $this->buildRequest('wp.getComments', $params);

        return $this->request($request);
    }

    function getComment($comment_id)
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
            $comment_id
        );

        $request = $this->buildRequest('wp.getComment', $params);

        return $this->request($request);
    }

    function getCommentCount($post_id)
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
            $post_id
        );

        $request = $this->buildRequest('wp.getCommentCount', $params);

        return $this->request($request);
    }

    function getCommentStatusList()
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
        );

        $request = $this->buildRequest('wp.getCommentStatusList', $params);
        return $this->request($request);
    }

    function newComment($post_id, $comment)
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
            $post_id,
            $comment
        );

        $request = $this->buildRequest('wp.newComment', $params);

        return $this->request($request);
    }

    function editComment($comment_id, $comment)
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
            $comment_id,
            $comment
        );

        $request = $this->buildRequest('wp.editComment', $params);

        return $this->request($request);
    }

    function deleteComment($comment_id)
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
            $comment_id
        );

        $request = $this->buildRequest('wp.deleteComment', $params);

        return $this->request($request);
    }
}
