<?php
/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * WordPress XML-RPC Config
 *
 * XML-RPC用コンフィグ
 *
 * PHP version 5
 *
 * LICENSE: This LICENSE is in the New BSD license style.
 *
 * @category  WordPress
 * @package   WordPress_Core
 * @author    Takahiro Ooishi <taka0125@users.sourceforge.jp>
 * @version   SVN : $Id$
 * @copyright 2009 Takahiro Ooishi
 * @license   http://opensource.org/licenses/bsd-license.php New BSD License
 * @link      http://code.google.com/p/wpalforphp/wiki/WordPressCoreConfig
 */

/**
 * WordPress XML-RPC Config
 *
 * XML-RPC用コンフィグ
 *
 * @category  WordPress
 * @package   WordPress_Core
 * @abstract
 * @author    Takahiro Ooishi <taka0125@users.sourceforge.jp>
 * @version   Release: @package_version@
 * @copyright 2009 Takahiro Ooishi
 * @license   http://opensource.org/licenses/bsd-license.php New BSD License
 * @link      http://code.google.com/p/wpalforphp/wiki/WordPressCoreConfig
 *
 */
abstract class WordPress_Core_Config
{
    protected $blogUrl;
    protected $xmlrpcUrl;
    protected $outputEncode = null;
    
    protected $username;
    protected $password;
    
    protected $blogId;
    
    function __construct($blog_url, $username = null, $password = null, $blog_id = null, $output_encode = WordPress_Encode::Utf8)
    {
        if (!$this->isValidBlogUrl($blog_url)) throw new Exception('invalid blog_url');
        $blog_url = $this->normalizeBlogUrl($blog_url);
        $this->blogUrl = $blog_url;
        $this->xmlrpcUrl = $this->buildXmlrpcUrl($blog_url);
        $this->setOutputEncode($output_encode);
        
        $this->setUsername($username);
        $this->setPassword($password);
        
        $this->setBlogId($blog_id);
    }

    function blogUrl()
    {
        return $this->blogUrl;
    }

    function xmlrpcUrl()
    {
        return $this->xmlrpcUrl;
    }

    function outputEncode()
    {
        return $this->outputEncode;
    }
    
    function username()
    {
        return $this->username;
    }

    function password()
    {
        return $this->password;
    }
    
    function blogId()
    {
        return $this->blogId;
    }

    function setUsername($username)
    {
        $this->username = $username;
    }

    function setPassword($password)
    {
        $this->password = $password;
    }

    function setOutputEncode($output_encode)
    {
        if (WordPress_Encode::isValidEncode($output_encode)) {
            $this->outputEncode = $output_encode;
        } else {
            $this->outputEncode = WordPress_Encode::Utf8;
        }
    }

    function setBlogId($blog_id)
    {
        $this->blogId = $blog_id;
    }

    protected function normalizeBlogUrl($blog_url)
    {
        if ($blog_url[strlen($blog_url) - 1] != '/') {
            $blog_url .= '/';
        }
        return $blog_url;
    }

    protected function buildXmlrpcUrl($blog_url)
    {
        return $blog_url . 'xmlrpc.php';
    }

    protected function isValidBlogUrl($blog_url)
    {
        if (!is_string($blog_url)) return false;
        if (!preg_match('/(http|https):\/\//', $blog_url)) return false;
        return true;
    }
}
