<?php
/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * WordPress XML-RPC 文字コード関連処理
 *
 * 文字コード関連処理を集めたクラス
 *
 * PHP version 5
 *
 * LICENSE: This LICENSE is in the New BSD license style.
 *
 * @category  WordPress
 * @package   WordPress_Core
 * @author    Takahiro Ooishi <taka0125@users.sourceforge.jp>
 * @version   SVN : $Id$
 * @copyright 2009 Takahiro Ooishi
 * @license   http://opensource.org/licenses/bsd-license.php New BSD License
 * @link      http://code.google.com/p/wpalforphp/wiki/WordPressCoreEncode
 */

/**
 * WordPress XML-RPC 文字コード関連処理
 *
 * 文字コード関連処理を集めたクラス
 *
 * @category  WordPress
 * @package   WordPress_Core
 * @abstract
 * @author    Takahiro Ooishi <taka0125@users.sourceforge.jp>
 * @version   Release: @package_version@
 * @copyright 2009 Takahiro Ooishi
 * @license   http://opensource.org/licenses/bsd-license.php New BSD License
 * @link      http://code.google.com/p/wpalforphp/wiki/WordPressCoreEncode
 *
 */

abstract class WordPress_Core_Encode
{
    const Utf8 = 'UTF-8';
    const ShiftJis = 'Shift_JIS';
    const EucJp = 'EUC-JP';
    const HtmlEntities = 'HTML-ENTITIES';

    protected function getEncodeList()
    {
        return array(
            self::Utf8 => true,
            self::ShiftJis => true,
            self::EucJp => true
        );
    }

    static function isValidEncode($encode)
    {
        $encode_list = self::getEncodeList();
        if (!isset($encode_list[$encode])) return false;
        if (!$encode_list[$encode]) return false;
        return true;
    }

    static function encode($params, $to_encode, $from_encode)
    {
        if (!is_array($params)) {
            return mb_convert_encoding($params, $to_encode, $from_encode);
        } else {
            foreach ($params as $key => $param) {
                $params[$key] = self::encode($param, $to_encode, $from_encode);
            }
            return $params;
        }
    }
}
