<?php
/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * WordPress XML-RPC Page関連API
 *
 * Page関連APIのクライアント
 *
 * PHP version 5
 *
 * LICENSE: This LICENSE is in the New BSD license style.
 *
 * @category  WordPress
 * @package   WordPress_Core
 * @author    Takahiro Ooishi <taka0125@users.sourceforge.jp>
 * @version   SVN : $Id$
 * @copyright 2009 Takahiro Ooishi
 * @license   http://opensource.org/licenses/bsd-license.php New BSD License
 * @link      http://code.google.com/p/wpalforphp/wiki/WordPressCorePageAPI
 * @see       http://codex.wordpress.org/XML-RPC_wp
 */

/**
 * WordPress XML-RPC Page関連API
 *
 * Page関連APIのクライアント
 *
 * @category  WordPress
 * @package   WordPress_Core
 * @abstract
 * @author    Takahiro Ooishi <taka0125@users.sourceforge.jp>
 * @version   Release: @package_version@
 * @copyright 2009 Takahiro Ooishi
 * @license   http://opensource.org/licenses/bsd-license.php New BSD License
 * @link      http://code.google.com/p/wpalforphp/wiki/WordPressCorePageAPI
 *
 */
class WordPress_Core_PageAPI extends WordPress_API
{
    function getPages()
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
        );

        $request = $this->buildRequest('wp.getPages', $params);

        return $this->request($request);
    }

    function getPage($page_id)
    {
        $params = array(
            $this->config->blogId(),
            $page_id,
            $this->config->username(),
            $this->config->password(),
        );

        $request = $this->buildRequest('wp.getPage', $params);

        return $this->request($request);
    }

    function getPageList()
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
        );

        $request = $this->buildRequest('wp.getPageList', $params);

        return $this->request($request);
    }

    function newPage($content)
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
            $content
        );

        $request = $this->buildRequest('wp.newPage', $params);

        return $this->request($request);
    }

    function editPage($page_id, $content)
    {
        $params = array(
            $this->config->blogId(),
            $page_id,
            $this->config->username(),
            $this->config->password(),
            $content
        );

        $request = $this->buildRequest('wp.editPage', $params);

        return $this->request($request);
    }

    function deletePage($page_id)
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
            $page_id
        );

        $request = $this->buildRequest('wp.deletePage', $params);

        return $this->request($request);
    }

    function getPageStatusList()
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
        );

        $request = $this->buildRequest('wp.getPageStatusList', $params);

        return $this->request($request);
    }

    function getPageTemplates()
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
        );

        $request = $this->buildRequest('wp.getPageTemplates', $params);

        return $this->request($request);
    }
}
