<?php
/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * WordPress XML-RPC Post関連API
 *
 * Post関連APIのクライアント
 *
 * PHP version 5
 *
 * LICENSE: This LICENSE is in the New BSD license style.
 *
 * @category  WordPress
 * @package   WordPress_Core
 * @author    Takahiro Ooishi <taka0125@users.sourceforge.jp>
 * @version   SVN : $Id$
 * @copyright 2009 Takahiro Ooishi
 * @license   http://opensource.org/licenses/bsd-license.php New BSD License
 * @link      http://code.google.com/p/wpalforphp/wiki/WordPressCorePostAPI
 * @see       http://www.na.rim.or.jp/~tsupo/program/blogTool/mt_xmlRpc.html#w01
 */

/**
 * WordPress XML-RPC Post関連API
 *
 * Post関連APIのクライアント
 *
 * @category  WordPress
 * @package   WordPress_Core
 * @abstract
 * @author    Takahiro Ooishi <taka0125@users.sourceforge.jp>
 * @version   Release: @package_version@
 * @copyright 2009 Takahiro Ooishi
 * @license   http://opensource.org/licenses/bsd-license.php New BSD License
 * @link      http://www.na.rim.or.jp/~tsupo/program/blogTool/mt_xmlRpc.html#w01
 *
 */
class WordPress_Core_PostAPI extends WordPress_API
{
    function newPost($content, $publish)
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
            $content,
            $publish
        );

        $request = $this->buildRequest('metaWeblog.newPost', $params);

        return $this->request($request);
    }
    
    function editPost($post_id, $content, $publish)
    {
        $params = array(
            $post_id,
            $this->config->username(),
            $this->config->password(),
            $content,
            $publish
        );

        $request = $this->buildRequest('metaWeblog.editPost', $params);

        return $this->request($request);
    }
    
    function getPost($post_id)
    {
        $params = array(
            $post_id,
            $this->config->username(),
            $this->config->password()
        );

        $request = $this->buildRequest('metaWeblog.getPost', $params);

        return $this->request($request);
    }

    function getRecentPosts($max_results)
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
            $max_results
        );

        $request = $this->buildRequest('metaWeblog.getRecentPosts', $params);

        return $this->request($request);
    }

    function getRecentPostTitles($max_results)
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
            $max_results
        );

        $request = $this->buildRequest('mt.getRecentPostTitles', $params);

        return $this->request($request);
    }

    function getPostStatusList()
    {
        $params = array(
            $this->config->blogId(),
            $this->config->username(),
            $this->config->password(),
        );

        $request = $this->buildRequest('wp.getPostStatusList', $params);

        return $this->request($request);
    }
}
